@@ -1,24 +1,10 @@
 /*
-    Copyright 2009 Dario Freddi <drf54321@gmail.com>
-    Copyright 2009 Will Stephenson <wstephenson@kde.org>
-    Copyright 2011-2012 Lamarque V. Souza <lamarque@kde.org>
-    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2009 Dario Freddi <drf54321@gmail.com>
+    SPDX-FileCopyrightText: 2009 Will Stephenson <wstephenson@kde.org>
+    SPDX-FileCopyrightText: 2011-2012 Lamarque V. Souza <lamarque@kde.org>
+    SPDX-FileCopyrightText: 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "service.h"
@@ -26,29 +12,30 @@
 #include <KPluginFactory>
 
 #include "connectivitymonitor.h"
-#include "secretagent.h"
-#include "notification.h"
 #include "monitor.h"
+#include "notification.h"
+#include "secretagent.h"
 
-#include <QDBusMetaType>
-#include <QDBusServiceWatcher>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
+#include <QDBusMetaType>
 #include <QDBusReply>
+#include <QDBusServiceWatcher>
 
 K_PLUGIN_CLASS_WITH_JSON(NetworkManagementService, "networkmanagement.json")
 
 class NetworkManagementServicePrivate
 {
-    public:
+public:
     SecretAgent *agent = nullptr;
     Notification *notification = nullptr;
     Monitor *monitor = nullptr;
     ConnectivityMonitor *connectivityMonitor = nullptr;
 };
 
-NetworkManagementService::NetworkManagementService(QObject * parent, const QVariantList&)
-    : KDEDModule(parent), d_ptr(new NetworkManagementServicePrivate)
+NetworkManagementService::NetworkManagementService(QObject *parent, const QVariantList &)
+    : KDEDModule(parent)
+    , d_ptr(new NetworkManagementServicePrivate)
 {
     Q_D(NetworkManagementService);
 
