@@ -7,7 +7,7 @@
 
 #include "connectioneditorbase.h"
 
-#include "debug.h"
+#include "plasma_nm_editor.h"
 #include "settings/bondwidget.h"
 #include "settings/bridgewidget.h"
 #include "settings/btwidget.h"
@@ -95,7 +95,7 @@ NMVariantMapMap ConnectionEditorBase::setting() const
         // add 802.1x security if needed
         QVariantMap security8021x;
         if (type == NetworkManager::Setting::typeAsString(NetworkManager::Setting::WirelessSecurity)) {
-            WifiSecurity *wifiSecurity = static_cast<WifiSecurity *>(widget);
+            auto wifiSecurity = static_cast<WifiSecurity *>(widget);
             if (wifiSecurity->enabled()) {
                 settings.insert(type, wifiSecurity->setting());
             }
@@ -104,7 +104,7 @@ NMVariantMapMap ConnectionEditorBase::setting() const
                 settings.insert(NetworkManager::Setting::typeAsString(NetworkManager::Setting::Security8021x), security8021x);
             }
         } else if (type == NetworkManager::Setting::typeAsString(NetworkManager::Setting::Security8021x)) {
-            WiredSecurity *wiredSecurity = static_cast<WiredSecurity *>(widget);
+            auto wiredSecurity = static_cast<WiredSecurity *>(widget);
             if (wiredSecurity->enabled8021x()) {
                 security8021x = static_cast<WiredSecurity *>(widget)->setting();
                 settings.insert(NetworkManager::Setting::typeAsString(NetworkManager::Setting::Security8021x), security8021x);
@@ -130,7 +130,7 @@ NMVariantMapMap ConnectionEditorBase::setting() const
 
         if (securitySetting && wirelessSetting) {
             if (securitySetting->keyMgmt() != NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting::Unknown) {
-                wirelessSetting->setSecurity("802-11-wireless-security");
+                wirelessSetting->setSecurity(QStringLiteral("802-11-wireless-security"));
             }
 
             if (securitySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::SAE
@@ -192,71 +192,70 @@ void ConnectionEditorBase::initialize()
     }
 
     // General configuration common to all connection types
-    ConnectionWidget *connectionWidget = new ConnectionWidget(m_connection);
+    auto connectionWidget = new ConnectionWidget(m_connection);
     addConnectionWidget(connectionWidget, i18nc("General", "General configuration"));
 
     // Add the rest of widgets
     QString serviceType;
     if (type == NetworkManager::ConnectionSettings::Wired) {
-        WiredConnectionWidget *wiredWidget = new WiredConnectionWidget(m_connection->setting(NetworkManager::Setting::Wired), this);
+        auto wiredWidget = new WiredConnectionWidget(m_connection->setting(NetworkManager::Setting::Wired), this);
         addSettingWidget(wiredWidget, i18n("Wired"));
-        WiredSecurity *wiredSecurity =
+        auto wiredSecurity =
             new WiredSecurity(m_connection->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>(), this);
         addSettingWidget(wiredSecurity, i18n("802.1x Security"));
     } else if (type == NetworkManager::ConnectionSettings::Wireless) {
-        WifiConnectionWidget *wifiWidget = new WifiConnectionWidget(m_connection->setting(NetworkManager::Setting::Wireless), this);
+        auto wifiWidget = new WifiConnectionWidget(m_connection->setting(NetworkManager::Setting::Wireless), this);
         addSettingWidget(wifiWidget, i18n("Wi-Fi"));
-        WifiSecurity *wifiSecurity =
-            new WifiSecurity(m_connection->setting(NetworkManager::Setting::WirelessSecurity),
-                             m_connection->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>(),
-                             this);
+        auto wifiSecurity = new WifiSecurity(m_connection->setting(NetworkManager::Setting::WirelessSecurity),
+                                             m_connection->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>(),
+                                             this);
         addSettingWidget(wifiSecurity, i18n("Wi-Fi Security"));
         connect(wifiWidget, QOverload<const QString &>::of(&WifiConnectionWidget::ssidChanged), wifiSecurity, &WifiSecurity::onSsidChanged);
     } else if (type == NetworkManager::ConnectionSettings::Pppoe) { // DSL
-        PppoeWidget *pppoeWidget = new PppoeWidget(m_connection->setting(NetworkManager::Setting::Pppoe), this);
+        auto pppoeWidget = new PppoeWidget(m_connection->setting(NetworkManager::Setting::Pppoe), this);
         addSettingWidget(pppoeWidget, i18n("DSL"));
-        WiredConnectionWidget *wiredWidget = new WiredConnectionWidget(m_connection->setting(NetworkManager::Setting::Wired), this);
+        auto wiredWidget = new WiredConnectionWidget(m_connection->setting(NetworkManager::Setting::Wired), this);
         addSettingWidget(wiredWidget, i18n("Wired"));
     } else if (type == NetworkManager::ConnectionSettings::Gsm) { // GSM
-        GsmWidget *gsmWidget = new GsmWidget(m_connection->setting(NetworkManager::Setting::Gsm), this);
+        auto gsmWidget = new GsmWidget(m_connection->setting(NetworkManager::Setting::Gsm), this);
         addSettingWidget(gsmWidget, i18n("Mobile Broadband (%1)", m_connection->typeAsString(m_connection->connectionType())));
     } else if (type == NetworkManager::ConnectionSettings::Cdma) { // CDMA
-        CdmaWidget *cdmaWidget = new CdmaWidget(m_connection->setting(NetworkManager::Setting::Cdma), this);
+        auto cdmaWidget = new CdmaWidget(m_connection->setting(NetworkManager::Setting::Cdma), this);
         addSettingWidget(cdmaWidget, i18n("Mobile Broadband (%1)", m_connection->typeAsString(m_connection->connectionType())));
     } else if (type == NetworkManager::ConnectionSettings::Bluetooth) { // Bluetooth
-        BtWidget *btWidget = new BtWidget(m_connection->setting(NetworkManager::Setting::Bluetooth), this);
+        auto btWidget = new BtWidget(m_connection->setting(NetworkManager::Setting::Bluetooth), this);
         addSettingWidget(btWidget, i18n("Bluetooth"));
         NetworkManager::BluetoothSetting::Ptr btSetting =
             m_connection->setting(NetworkManager::Setting::Bluetooth).staticCast<NetworkManager::BluetoothSetting>();
         if (btSetting->profileType() == NetworkManager::BluetoothSetting::Dun) {
-            GsmWidget *gsmWidget = new GsmWidget(m_connection->setting(NetworkManager::Setting::Gsm), this);
+            auto gsmWidget = new GsmWidget(m_connection->setting(NetworkManager::Setting::Gsm), this);
             addSettingWidget(gsmWidget, i18n("GSM"));
-            PPPWidget *pppWidget = new PPPWidget(m_connection->setting(NetworkManager::Setting::Ppp), this);
+            auto pppWidget = new PPPWidget(m_connection->setting(NetworkManager::Setting::Ppp), this);
             addSettingWidget(pppWidget, i18n("PPP"));
         }
     } else if (type == NetworkManager::ConnectionSettings::Infiniband) { // Infiniband
-        InfinibandWidget *infinibandWidget = new InfinibandWidget(m_connection->setting(NetworkManager::Setting::Infiniband), this);
+        auto infinibandWidget = new InfinibandWidget(m_connection->setting(NetworkManager::Setting::Infiniband), this);
         addSettingWidget(infinibandWidget, i18n("Infiniband"));
     } else if (type == NetworkManager::ConnectionSettings::Bond) { // Bond
-        BondWidget *bondWidget = new BondWidget(m_connection->uuid(), m_connection->id(), m_connection->setting(NetworkManager::Setting::Bond), this);
+        auto bondWidget = new BondWidget(m_connection->uuid(), m_connection->id(), m_connection->setting(NetworkManager::Setting::Bond), this);
         addSettingWidget(bondWidget, i18n("Bond"));
     } else if (type == NetworkManager::ConnectionSettings::Bridge) { // Bridge
-        BridgeWidget *bridgeWidget = new BridgeWidget(m_connection->uuid(), m_connection->id(), m_connection->setting(NetworkManager::Setting::Bridge), this);
+        auto bridgeWidget = new BridgeWidget(m_connection->uuid(), m_connection->id(), m_connection->setting(NetworkManager::Setting::Bridge), this);
         addSettingWidget(bridgeWidget, i18n("Bridge"));
     } else if (type == NetworkManager::ConnectionSettings::Vlan) { // Vlan
-        VlanWidget *vlanWidget = new VlanWidget(m_connection->setting(NetworkManager::Setting::Vlan), this);
+        auto vlanWidget = new VlanWidget(m_connection->setting(NetworkManager::Setting::Vlan), this);
         addSettingWidget(vlanWidget, i18n("Vlan"));
     } else if (type == NetworkManager::ConnectionSettings::Team) { // Team
-        TeamWidget *teamWidget = new TeamWidget(m_connection->uuid(), m_connection->id(), m_connection->setting(NetworkManager::Setting::Team), this);
+        auto teamWidget = new TeamWidget(m_connection->uuid(), m_connection->id(), m_connection->setting(NetworkManager::Setting::Team), this);
         addSettingWidget(teamWidget, i18n("Team"));
     } else if (type == NetworkManager::ConnectionSettings::WireGuard) { // WireGuard
-        WireGuardInterfaceWidget *wireGuardInterfaceWidget = new WireGuardInterfaceWidget(m_connection->setting(NetworkManager::Setting::WireGuard), this);
+        auto wireGuardInterfaceWidget = new WireGuardInterfaceWidget(m_connection->setting(NetworkManager::Setting::WireGuard), this);
         addSettingWidget(wireGuardInterfaceWidget, i18n("WireGuard Interface"));
     } else if (type == NetworkManager::ConnectionSettings::Vpn) { // VPN
         QString error;
         NetworkManager::VpnSetting::Ptr vpnSetting = m_connection->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
         if (!vpnSetting) {
-            qCWarning(PLASMA_NM) << "Missing VPN setting!";
+            qCWarning(PLASMA_NM_EDITOR_LOG) << "Missing VPN setting!";
         } else {
             serviceType = vpnSetting->serviceType();
 
@@ -267,7 +266,7 @@ void ConnectionEditorBase::initialize()
                 SettingWidget *vpnWidget = result.plugin->widget(vpnSetting, this);
                 addSettingWidget(vpnWidget, i18n("VPN (%1)", shortName));
             } else {
-                qCWarning(PLASMA_NM) << "Could not instantiate VPN UI plugin" << result.errorText;
+                qCWarning(PLASMA_NM_EDITOR_LOG) << "Could not instantiate VPN UI plugin" << result.errorText;
             }
         }
     }
@@ -275,13 +274,13 @@ void ConnectionEditorBase::initialize()
     // PPP widget
     if (type == NetworkManager::ConnectionSettings::Pppoe || type == NetworkManager::ConnectionSettings::Cdma
         || type == NetworkManager::ConnectionSettings::Gsm) {
-        PPPWidget *pppWidget = new PPPWidget(m_connection->setting(NetworkManager::Setting::Ppp), this);
+        auto pppWidget = new PPPWidget(m_connection->setting(NetworkManager::Setting::Ppp), this);
         addSettingWidget(pppWidget, i18n("PPP"));
     }
 
     // IPv4 widget
     if (!m_connection->isSlave()) {
-        IPv4Widget *ipv4Widget = new IPv4Widget(m_connection->setting(NetworkManager::Setting::Ipv4), this);
+        auto ipv4Widget = new IPv4Widget(m_connection->setting(NetworkManager::Setting::Ipv4), this);
         addSettingWidget(ipv4Widget, i18n("IPv4"));
     }
 
@@ -298,13 +297,13 @@ void ConnectionEditorBase::initialize()
          || type == NetworkManager::ConnectionSettings::WireGuard //
          || (type == NetworkManager::ConnectionSettings::Vpn && serviceType == QLatin1String("org.freedesktop.NetworkManager.openvpn")))
         && !m_connection->isSlave()) {
-        IPv6Widget *ipv6Widget = new IPv6Widget(m_connection->setting(NetworkManager::Setting::Ipv6), this);
+        auto ipv6Widget = new IPv6Widget(m_connection->setting(NetworkManager::Setting::Ipv6), this);
         addSettingWidget(ipv6Widget, i18n("IPv6"));
     }
 
     // Re-check validation
     bool valid = true;
-    for (SettingWidget *widget : m_settingWidgets) {
+    for (SettingWidget *widget : qAsConst(m_settingWidgets)) {
         valid = valid && widget->isValid();
         connect(widget, &SettingWidget::validChanged, this, &ConnectionEditorBase::validChanged);
     }
@@ -329,7 +328,7 @@ void ConnectionEditorBase::initialize()
                 if (adslSetting && !adslSetting->needSecrets().isEmpty()) {
                     requiredSecrets = adslSetting->needSecrets();
                     setting = adslSetting->toMap();
-                    settingName = QLatin1String("adsl");
+                    settingName = QStringLiteral("adsl");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Bluetooth) {
                 NetworkManager::GsmSetting::Ptr gsmSetting =
@@ -337,7 +336,7 @@ void ConnectionEditorBase::initialize()
                 if (gsmSetting && !gsmSetting->needSecrets().isEmpty()) {
                     requiredSecrets = gsmSetting->needSecrets();
                     setting = gsmSetting->toMap();
-                    settingName = QLatin1String("gsm");
+                    settingName = QStringLiteral("gsm");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Cdma) {
                 NetworkManager::CdmaSetting::Ptr cdmaSetting =
@@ -345,7 +344,7 @@ void ConnectionEditorBase::initialize()
                 if (cdmaSetting && !cdmaSetting->needSecrets().isEmpty()) {
                     requiredSecrets = cdmaSetting->needSecrets();
                     setting = cdmaSetting->toMap();
-                    settingName = QLatin1String("cdma");
+                    settingName = QStringLiteral("cdma");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Gsm) {
                 NetworkManager::GsmSetting::Ptr gsmSetting =
@@ -353,7 +352,7 @@ void ConnectionEditorBase::initialize()
                 if (gsmSetting && !gsmSetting->needSecrets().isEmpty()) {
                     requiredSecrets = gsmSetting->needSecrets();
                     setting = gsmSetting->toMap();
-                    settingName = QLatin1String("gsm");
+                    settingName = QStringLiteral("gsm");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Pppoe) {
                 NetworkManager::PppoeSetting::Ptr pppoeSetting =
@@ -361,7 +360,7 @@ void ConnectionEditorBase::initialize()
                 if (pppoeSetting && !pppoeSetting->needSecrets().isEmpty()) {
                     requiredSecrets = pppoeSetting->needSecrets();
                     setting = pppoeSetting->toMap();
-                    settingName = QLatin1String("pppoe");
+                    settingName = QStringLiteral("pppoe");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Wired) {
                 NetworkManager::Security8021xSetting::Ptr securitySetting =
@@ -369,7 +368,7 @@ void ConnectionEditorBase::initialize()
                 if (securitySetting && !securitySetting->needSecrets().isEmpty()) {
                     requiredSecrets = securitySetting->needSecrets();
                     setting = securitySetting->toMap();
-                    settingName = QLatin1String("802-1x");
+                    settingName = QStringLiteral("802-1x");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::WireGuard) {
                 NetworkManager::WireGuardSetting::Ptr securitySetting =
@@ -377,7 +376,7 @@ void ConnectionEditorBase::initialize()
                 if (securitySetting && !securitySetting->needSecrets().isEmpty()) {
                     requiredSecrets = securitySetting->needSecrets();
                     setting = securitySetting->toMap();
-                    settingName = QLatin1String("wireguard");
+                    settingName = QStringLiteral("wireguard");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
                 NetworkManager::WirelessSecuritySetting::Ptr wifiSecuritySetting =
@@ -391,7 +390,7 @@ void ConnectionEditorBase::initialize()
                     if (securitySetting && !securitySetting->needSecrets().isEmpty()) {
                         requiredSecrets = securitySetting->needSecrets();
                         setting = securitySetting->toMap();
-                        settingName = QLatin1String("802-1x");
+                        settingName = QStringLiteral("802-1x");
 
                         if (requiredSecrets.contains(NM_SETTING_802_1X_PASSWORD_RAW)) {
                             requiredSecrets.removeAll(NM_SETTING_802_1X_PASSWORD_RAW);
@@ -401,11 +400,11 @@ void ConnectionEditorBase::initialize()
                     if (!wifiSecuritySetting->needSecrets().isEmpty()) {
                         requiredSecrets = wifiSecuritySetting->needSecrets();
                         setting = wifiSecuritySetting->toMap();
-                        settingName = QLatin1String("802-11-wireless-security");
+                        settingName = QStringLiteral("802-11-wireless-security");
                     }
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Vpn) {
-                settingName = QLatin1String("vpn");
+                settingName = QStringLiteral("vpn");
             }
 
             if (!requiredSecrets.isEmpty() || m_connection->connectionType() == NetworkManager::ConnectionSettings::Vpn) {
@@ -422,7 +421,7 @@ void ConnectionEditorBase::initialize()
                         }
                     }
                 } else {
-                    for (const QString &secret : requiredSecrets) {
+                    for (const QString &secret : qAsConst(requiredSecrets)) {
                         if (setting.contains(secret + QLatin1String("-flags"))) {
                             NetworkManager::Setting::SecretFlagType secretFlag =
                                 (NetworkManager::Setting::SecretFlagType)setting.value(secret + QLatin1String("-flags")).toInt();
@@ -438,7 +437,7 @@ void ConnectionEditorBase::initialize()
                 if (requestSecrets) {
                     m_pendingReplies++;
                     reply = connection->secrets(settingName);
-                    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+                    auto watcher = new QDBusPendingCallWatcher(reply, this);
                     watcher->setProperty("connection", connection->name());
                     watcher->setProperty("settingName", settingName);
                     connect(watcher, &QDBusPendingCallWatcher::finished, this, &ConnectionEditorBase::replyFinished);
@@ -467,7 +466,7 @@ void ConnectionEditorBase::replyFinished(QDBusPendingCallWatcher *watcher)
                 NetworkManager::Setting::Ptr setting = m_connection->setting(NetworkManager::Setting::typeFromString(key));
                 if (setting) {
                     setting->secretsFromMap(secrets.value(key));
-                    for (SettingWidget *widget : m_settingWidgets) {
+                    for (SettingWidget *widget : qAsConst(m_settingWidgets)) {
                         const QString type = widget->type();
                         if (type == settingName
                             || (settingName == NetworkManager::Setting::typeAsString(NetworkManager::Setting::Security8021x)
@@ -479,8 +478,8 @@ void ConnectionEditorBase::replyFinished(QDBusPendingCallWatcher *watcher)
             }
         }
     } else {
-        KNotification *notification = new KNotification("FailedToGetSecrets", KNotification::CloseOnTimeout);
-        notification->setComponentName("networkmanagement");
+        auto notification = new KNotification(QStringLiteral("FailedToGetSecrets"), KNotification::CloseOnTimeout);
+        notification->setComponentName(QStringLiteral("networkmanagement"));
         notification->setTitle(i18n("Failed to get secrets for %1", watcher->property("connection").toString()));
         notification->setText(reply.error().message());
         notification->setIconName(QStringLiteral("dialog-warning"));
@@ -502,7 +501,7 @@ void ConnectionEditorBase::validChanged(bool valid)
         Q_EMIT validityChanged(false);
         return;
     } else {
-        for (SettingWidget *widget : m_settingWidgets) {
+        for (SettingWidget *widget : qAsConst(m_settingWidgets)) {
             if (!widget->isValid()) {
                 m_valid = false;
                 Q_EMIT validityChanged(false);
