@@ -11,13 +11,10 @@
 
 ListValidator::ListValidator(QObject *parent)
     : QValidator(parent)
-    , inner(nullptr)
 {
 }
 
-ListValidator::~ListValidator()
-{
-}
+ListValidator::~ListValidator() = default;
 
 QValidator::State ListValidator::validate(QString &text, int &pos) const
 {
