@@ -51,7 +51,7 @@ public:
     Private()
         : model(0, 3)
     {
-        QStandardItem *headerItem = new QStandardItem(i18nc("Header text for IPv4 address", "Address"));
+        auto headerItem = new QStandardItem(i18nc("Header text for IPv4 address", "Address"));
         model.setHorizontalHeaderItem(0, headerItem);
         headerItem = new QStandardItem(i18nc("Header text for IPv4 netmask", "Netmask"));
         model.setHorizontalHeaderItem(1, headerItem);
@@ -72,7 +72,7 @@ IPv4Widget::IPv4Widget(const NetworkManager::Setting::Ptr &setting, QWidget *par
     m_ui->tableViewAddresses->horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
     m_ui->tableViewAddresses->horizontalHeader()->setStretchLastSection(true);
 
-    IpV4Delegate *ipDelegate = new IpV4Delegate(this);
+    auto ipDelegate = new IpV4Delegate(this);
     m_ui->tableViewAddresses->setItemDelegateForColumn(0, ipDelegate);
     m_ui->tableViewAddresses->setItemDelegateForColumn(1, ipDelegate);
     m_ui->tableViewAddresses->setItemDelegateForColumn(2, ipDelegate);
@@ -160,8 +160,8 @@ void IPv4Widget::loadConfig(const NetworkManager::Setting::Ptr &setting)
     for (const QHostAddress &addr : ipv4Setting->dns()) {
         tmp.append(addr.toString());
     }
-    m_ui->dns->setText(tmp.join(","));
-    m_ui->dnsSearch->setText(ipv4Setting->dnsSearch().join(","));
+    m_ui->dns->setText(tmp.join(QStringLiteral(",")));
+    m_ui->dnsSearch->setText(ipv4Setting->dnsSearch().join(QStringLiteral(",")));
 
     m_ui->dhcpClientId->setText(ipv4Setting->dhcpClientId());
 
@@ -222,7 +222,7 @@ QVariantMap IPv4Widget::setting() const
 
     // dns
     if (m_ui->dns->isEnabled() && !m_ui->dns->text().isEmpty()) {
-        QStringList tmp = m_ui->dns->text().split(',');
+        QStringList tmp = m_ui->dns->text().split(QLatin1Char(','));
         QList<QHostAddress> tmpAddrList;
         for (const QString &str : tmp) {
             QHostAddress addr(str);
@@ -232,7 +232,7 @@ QVariantMap IPv4Widget::setting() const
         ipv4Setting.setDns(tmpAddrList);
     }
     if (m_ui->dnsSearch->isEnabled() && !m_ui->dnsSearch->text().isEmpty()) {
-        ipv4Setting.setDnsSearch(m_ui->dnsSearch->text().split(','));
+        ipv4Setting.setDnsSearch(m_ui->dnsSearch->text().split(QLatin1Char(',')));
     }
 
     // dhcp id
@@ -441,7 +441,7 @@ void IPv4Widget::slotAdvancedDialog()
     dadTimeout->setValue(m_tmpIpv4Setting.dadTimeout());
     layout->addRow(i18n("DAD timeout:"), dadTimeout);
 
-    QDialogButtonBox *box = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dlg);
+    auto box = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dlg);
     connect(box, &QDialogButtonBox::accepted, dlg, &QDialog::accept);
     connect(box, &QDialogButtonBox::rejected, dlg, &QDialog::reject);
     layout->addWidget(box);
@@ -461,16 +461,16 @@ void IPv4Widget::slotDnsServers()
     QPointer<QDialog> dialog = new QDialog(this);
     dialog->setWindowTitle(i18n("Edit DNS servers"));
     dialog->setLayout(new QVBoxLayout);
-    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dialog);
+    auto buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dialog);
     connect(buttons, &QDialogButtonBox::accepted, dialog.data(), &QDialog::accept);
     connect(buttons, &QDialogButtonBox::rejected, dialog.data(), &QDialog::reject);
-    KEditListWidget *listWidget = new KEditListWidget(dialog);
-    listWidget->setItems(m_ui->dns->text().split(',').replaceInStrings(" ", ""));
+    auto listWidget = new KEditListWidget(dialog);
+    listWidget->setItems(m_ui->dns->text().split(QLatin1Char(',')).replaceInStrings(QStringLiteral(" "), QLatin1String("")));
     listWidget->lineEdit()->setFocus(Qt::OtherFocusReason);
     dialog->layout()->addWidget(listWidget);
     dialog->layout()->addWidget(buttons);
     connect(dialog.data(), &QDialog::accepted, [listWidget, this]() {
-        QString text = listWidget->items().join(",");
+        QString text = listWidget->items().join(QStringLiteral(","));
         if (text.endsWith(',')) {
             text.chop(1);
         }
@@ -490,16 +490,16 @@ void IPv4Widget::slotDnsDomains()
     QPointer<QDialog> dialog = new QDialog(this);
     dialog->setWindowTitle(i18n("Edit DNS search domains"));
     dialog->setLayout(new QVBoxLayout);
-    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dialog);
+    auto buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dialog);
     connect(buttons, &QDialogButtonBox::accepted, dialog.data(), &QDialog::accept);
     connect(buttons, &QDialogButtonBox::rejected, dialog.data(), &QDialog::reject);
-    KEditListWidget *listWidget = new KEditListWidget(dialog);
-    listWidget->setItems(m_ui->dnsSearch->text().split(',').replaceInStrings(" ", ""));
+    auto listWidget = new KEditListWidget(dialog);
+    listWidget->setItems(m_ui->dnsSearch->text().split(QLatin1Char(',')).replaceInStrings(QStringLiteral(" "), QLatin1String("")));
     listWidget->lineEdit()->setFocus(Qt::OtherFocusReason);
     dialog->layout()->addWidget(listWidget);
     dialog->layout()->addWidget(buttons);
     connect(dialog.data(), &QDialog::accepted, [listWidget, this]() {
-        QString text = listWidget->items().join(",");
+        QString text = listWidget->items().join(QStringLiteral(","));
         if (text.endsWith(',')) {
             text.chop(1);
         }
@@ -534,7 +534,7 @@ bool IPv4Widget::isValid() const
 
     if (!m_ui->dns->text().isEmpty()
         && (m_ui->method->currentIndex() == Automatic || m_ui->method->currentIndex() == Manual || m_ui->method->currentIndex() == AutomaticOnlyIP)) {
-        const QStringList tmp = m_ui->dns->text().split(',');
+        const QStringList tmp = m_ui->dns->text().split(QLatin1Char(','));
         for (const QString &str : tmp) {
             QHostAddress addr(str);
             if (addr.isNull()) {
