@@ -6,7 +6,7 @@
 
 #include "teamwidget.h"
 #include "connectioneditordialog.h"
-#include "debug.h"
+#include "plasma_nm_editor.h"
 #include "ui_team.h"
 
 #include <QDBusPendingReply>
@@ -26,12 +26,12 @@ TeamWidget::TeamWidget(const QString &masterUuid, const QString &masterId, const
     , m_uuid(masterUuid)
     , m_id(masterId)
     , m_ui(new Ui::TeamWidget)
+    , m_menu(new QMenu(this))
 {
     m_ui->setupUi(this);
 
     // Action buttons and menu
-    m_menu = new QMenu(this);
-    QAction *action = new QAction(i18n("Ethernet"), this);
+    auto action = new QAction(i18n("Ethernet"), this);
     action->setData(NetworkManager::ConnectionSettings::Wired);
     m_menu->addAction(action);
     action = new QAction(i18n("Infiniband"), this);
@@ -92,9 +92,9 @@ QVariantMap TeamWidget::setting() const
 
 void TeamWidget::addTeam(QAction *action)
 {
-    qCDebug(PLASMA_NM) << "Adding teamed connection:" << action->data();
-    qCDebug(PLASMA_NM) << "Master UUID:" << m_uuid;
-    qCDebug(PLASMA_NM) << "Slave type:" << type();
+    qCDebug(PLASMA_NM_EDITOR_LOG) << "Adding teamed connection:" << action->data();
+    qCDebug(PLASMA_NM_EDITOR_LOG) << "Master UUID:" << m_uuid;
+    qCDebug(PLASMA_NM_EDITOR_LOG) << "Slave type:" << type();
 
     NetworkManager::ConnectionSettings::ConnectionType connectionType = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(action->data().toInt());
     NetworkManager::ConnectionSettings::Ptr connectionSettings =
@@ -106,10 +106,10 @@ void TeamWidget::addTeam(QAction *action)
 
     QPointer<ConnectionEditorDialog> teamEditor = new ConnectionEditorDialog(connectionSettings);
     connect(teamEditor.data(), &ConnectionEditorDialog::accepted, [teamEditor, this]() {
-        qCDebug(PLASMA_NM) << "Saving slave connection";
-        // qCDebug(PLASMA_NM) << teamEditor->setting();
+        qCDebug(PLASMA_NM_EDITOR_LOG) << "Saving slave connection";
+        // qCDebug(PLASMA_NM_EDITOR_LOG) << teamEditor->setting();
         QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addConnection(teamEditor->setting());
-        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+        auto watcher = new QDBusPendingCallWatcher(reply, this);
         connect(watcher, &QDBusPendingCallWatcher::finished, this, &TeamWidget::teamAddComplete);
     });
     connect(teamEditor.data(), &ConnectionEditorDialog::finished, [teamEditor]() {
@@ -137,14 +137,13 @@ void TeamWidget::teamAddComplete(QDBusPendingCallWatcher *watcher)
         // find the slave connection with matching UUID
         NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(reply.value().path());
         if (connection && connection->settings()->master() == m_uuid) {
-            const QString label =
-                QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
-            QListWidgetItem *slaveItem = new QListWidgetItem(label, m_ui->teams);
+            const QString label = QString("%1 (%2)").arg(connection->name(), connection->settings()->typeAsString(connection->settings()->connectionType()));
+            auto slaveItem = new QListWidgetItem(label, m_ui->teams);
             slaveItem->setData(Qt::UserRole, connection->uuid());
             slotWidgetChanged();
         }
     } else {
-        qCWarning(PLASMA_NM) << "Teamed connection not added:" << reply.error().message();
+        qCWarning(PLASMA_NM_EDITOR_LOG) << "Teamed connection not added:" << reply.error().message();
     }
 }
 
@@ -158,7 +157,7 @@ void TeamWidget::editTeam()
     NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(uuid);
 
     if (connection) {
-        qCDebug(PLASMA_NM) << "Editing teamed connection" << currentItem->text() << uuid;
+        qCDebug(PLASMA_NM_EDITOR_LOG) << "Editing teamed connection" << currentItem->text() << uuid;
         QPointer<ConnectionEditorDialog> teamEditor = new ConnectionEditorDialog(connection->settings());
         connect(teamEditor.data(), &ConnectionEditorDialog::accepted, [connection, teamEditor, this]() {
             connection->update(teamEditor->setting());
@@ -184,7 +183,7 @@ void TeamWidget::deleteTeam()
     NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(uuid);
 
     if (connection) {
-        qCDebug(PLASMA_NM) << "About to delete teamed connection" << currentItem->text() << uuid;
+        qCDebug(PLASMA_NM_EDITOR_LOG) << "About to delete teamed connection" << currentItem->text() << uuid;
         if (KMessageBox::questionYesNo(this,
                                        i18n("Do you want to remove the connection '%1'?", connection->name()),
                                        i18n("Remove Connection"),
@@ -213,8 +212,8 @@ void TeamWidget::populateTeams()
                         (!m_id.isEmpty() && master == m_id)); // by-name
         if (isSlave && (settings->slaveType() == type())) {
             const QString label =
-                QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
-            QListWidgetItem *slaveItem = new QListWidgetItem(label, m_ui->teams);
+                QStringLiteral("%1 (%2)").arg(connection->name(), connection->settings()->typeAsString(connection->settings()->connectionType()));
+            auto slaveItem = new QListWidgetItem(label, m_ui->teams);
             slaveItem->setData(Qt::UserRole, connection->uuid());
         }
     }
@@ -225,7 +224,7 @@ void TeamWidget::importConfig()
     const QString filename =
         QFileDialog::getOpenFileName(this, i18n("Select file to import"), QStandardPaths::writableLocation(QStandardPaths::HomeLocation), "text/plain");
     if (!filename.isEmpty()) {
-        // qCDebug(PLASMA_NM) << "Importing" << filename;
+        // qCDebug(PLASMA_NM_EDITOR_LOG) << "Importing" << filename;
         QFile file(filename);
         if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             QTextStream stream(&file);
