@@ -6,8 +6,8 @@
 
 #include "networkmodel.h"
 #include "configuration.h"
-#include "debug.h"
 #include "networkmodelitem.h"
+#include "plasma_nm_libs.h"
 #include "uiutils.h"
 
 #if WITH_MODEMMANAGER_SUPPORT
@@ -23,9 +23,7 @@ NetworkModel::NetworkModel(QObject *parent)
     initialize();
 }
 
-NetworkModel::~NetworkModel()
-{
-}
+NetworkModel::~NetworkModel() = default;
 
 QVariant NetworkModel::data(const QModelIndex &index, int role) const
 {
@@ -100,7 +98,7 @@ QVariant NetworkModel::data(const QModelIndex &index, int role) const
         }
     }
 
-    return QVariant();
+    return {};
 }
 
 int NetworkModel::rowCount(const QModelIndex &parent) const
@@ -237,13 +235,13 @@ void NetworkModel::initializeSignals(const NetworkManager::Device::Ptr &device)
 
     auto deviceStatistics = device->deviceStatistics();
     connect(deviceStatistics.data(), &NetworkManager::DeviceStatistics::rxBytesChanged, this, [this, device](qulonglong rxBytes) {
-        for (auto *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
+        for (auto item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
             item->setRxBytes(rxBytes);
             updateItem(item);
         }
     });
     connect(deviceStatistics.data(), &NetworkManager::DeviceStatistics::txBytesChanged, this, [this, device](qulonglong txBytes) {
-        for (auto *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
+        for (auto item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
             item->setTxBytes(txBytes);
             updateItem(item);
         }
@@ -332,7 +330,7 @@ void NetworkModel::addActiveConnection(const NetworkManager::ActiveConnection::P
                 item->setVpnState(state);
             }
             item->invalidateDetails();
-            qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection state changed to " << item->connectionState();
+            qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": active connection state changed to " << item->connectionState();
 
             if (device && device->uni() == item->devicePath()) {
                 auto deviceStatistics = device->deviceStatistics();
@@ -366,7 +364,7 @@ void NetworkModel::addAvailableConnection(const QString &connection, const Netwo
 
         item->setDevicePath(device->uni());
         item->setDeviceState(device->state());
-        qCDebug(PLASMA_NM) << "Item " << item->name() << ": device changed to " << item->devicePath();
+        qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": device changed to " << item->devicePath();
 #if WITH_MODEMMANAGER_SUPPORT
         if (device->type() == NetworkManager::Device::Modem) {
             ModemManager::ModemDevice::Ptr modemDevice = ModemManager::findModemDevice(device->udi());
@@ -374,7 +372,7 @@ void NetworkModel::addAvailableConnection(const QString &connection, const Netwo
                 ModemManager::Modem::Ptr modemInterface = modemDevice->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
                 if (modemInterface) {
                     item->setSignal(modemInterface->signalQuality().signal);
-                    qCDebug(PLASMA_NM) << "Item " << item->name() << ": signal changed to " << item->signal();
+                    qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": signal changed to " << item->signal();
                 }
             }
         }
@@ -384,7 +382,7 @@ void NetworkModel::addAvailableConnection(const QString &connection, const Netwo
             for (NetworkModelItem *secondItem : m_list.returnItems(NetworkItemsList::Ssid, item->ssid())) {
                 if (secondItem->itemType() == NetworkModelItem::AvailableAccessPoint && secondItem->devicePath() == item->devicePath()) {
                     removeItem(secondItem);
-                    qCDebug(PLASMA_NM) << "Access point " << secondItem->name() << ": merged to " << item->name() << " connection";
+                    qCDebug(PLASMA_NM_LIBS_LOG) << "Access point " << secondItem->name() << ": merged to " << item->name() << " connection";
                     break;
                 }
             }
@@ -427,7 +425,7 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr &connecti
         return;
     }
 
-    NetworkModelItem *item = new NetworkModelItem();
+    auto item = new NetworkModelItem();
     item->setConnectionPath(connection->path());
     item->setName(settings->id());
     item->setTimestamp(settings->timestamp());
@@ -446,7 +444,7 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr &connecti
     item->invalidateDetails();
 
     insertItem(item);
-    qCDebug(PLASMA_NM) << "New connection " << item->name() << " added";
+    qCDebug(PLASMA_NM_LIBS_LOG) << "New connection " << item->name() << " added";
 }
 
 void NetworkModel::addDevice(const NetworkManager::Device::Ptr &device)
@@ -525,7 +523,7 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
         }
     }
 
-    NetworkModelItem *item = new NetworkModelItem();
+    auto item = new NetworkModelItem();
     if (device->ipInterfaceName().isEmpty()) {
         item->setDeviceName(device->interfaceName());
     } else {
@@ -542,7 +540,7 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
     item->invalidateDetails();
 
     insertItem(item);
-    qCDebug(PLASMA_NM) << "New wireless network " << item->name() << " added";
+    qCDebug(PLASMA_NM_LIBS_LOG) << "New wireless network " << item->name() << " added";
 }
 
 void NetworkModel::checkAndCreateDuplicate(const QString &connection, const QString &deviceUni)
@@ -562,7 +560,7 @@ void NetworkModel::checkAndCreateDuplicate(const QString &connection, const QStr
     }
 
     if (createDuplicate) {
-        NetworkModelItem *duplicatedItem = new NetworkModelItem(originalItem);
+        auto duplicatedItem = new NetworkModelItem(originalItem);
         duplicatedItem->invalidateDetails();
 
         insertItem(duplicatedItem);
@@ -571,7 +569,7 @@ void NetworkModel::checkAndCreateDuplicate(const QString &connection, const QStr
 
 void NetworkModel::onItemUpdated()
 {
-    NetworkModelItem *item = static_cast<NetworkModelItem *>(sender());
+    auto item = static_cast<NetworkModelItem *>(sender());
     if (item) {
         updateItem(item);
     }
@@ -636,7 +634,7 @@ void NetworkModel::updateItem(NetworkModelItem *item)
 
 void NetworkModel::accessPointSignalStrengthChanged(int signal)
 {
-    NetworkManager::AccessPoint *apPtr = qobject_cast<NetworkManager::AccessPoint *>(sender());
+    auto apPtr = qobject_cast<NetworkManager::AccessPoint *>(sender());
     if (!apPtr) {
         return;
     }
@@ -645,7 +643,7 @@ void NetworkModel::accessPointSignalStrengthChanged(int signal)
         if (item->specificPath() == apPtr->uni()) {
             item->setSignal(signal);
             updateItem(item);
-            qCDebug(PLASMA_NM) << "AccessPoint " << item->name() << ": signal changed to " << item->signal();
+            qCDebug(PLASMA_NM_LIBS_LOG) << "AccessPoint " << item->name() << ": signal changed to " << item->signal();
         }
     }
 }
@@ -666,13 +664,13 @@ void NetworkModel::activeConnectionRemoved(const QString &activeConnection)
         item->setConnectionState(NetworkManager::ActiveConnection::Deactivated);
         item->setVpnState(NetworkManager::VpnConnection::Disconnected);
         updateItem(item);
-        qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection removed";
+        qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": active connection removed";
     }
 }
 
 void NetworkModel::activeConnectionStateChanged(NetworkManager::ActiveConnection::State state)
 {
-    NetworkManager::ActiveConnection *activePtr = qobject_cast<NetworkManager::ActiveConnection *>(sender());
+    auto activePtr = qobject_cast<NetworkManager::ActiveConnection *>(sender());
 
     if (!activePtr) {
         return;
@@ -681,14 +679,14 @@ void NetworkModel::activeConnectionStateChanged(NetworkManager::ActiveConnection
     for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::ActiveConnection, activePtr->path())) {
         item->setConnectionState(state);
         updateItem(item);
-        qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
+        qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
     }
 }
 
 void NetworkModel::activeVpnConnectionStateChanged(NetworkManager::VpnConnection::State state, NetworkManager::VpnConnection::StateChangeReason reason)
 {
     Q_UNUSED(reason)
-    NetworkManager::ActiveConnection *activePtr = qobject_cast<NetworkManager::ActiveConnection *>(sender());
+    auto activePtr = qobject_cast<NetworkManager::ActiveConnection *>(sender());
 
     if (!activePtr) {
         return;
@@ -707,7 +705,7 @@ void NetworkModel::activeVpnConnectionStateChanged(NetworkManager::VpnConnection
         }
         item->setVpnState(state);
         updateItem(item);
-        qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
+        qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
     }
 }
 
@@ -749,7 +747,7 @@ void NetworkModel::availableConnectionDisappeared(const QString &connection)
             item->setDeviceState(NetworkManager::Device::UnknownState);
             item->setSignal(0);
             item->setSpecificPath(QString());
-            qCDebug(PLASMA_NM) << "Item " << item->name() << " removed as available connection";
+            qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << " removed as available connection";
             // Check whether the connection is still available as an access point, this happens
             // when we change its properties, like ssid, bssid, security etc.
             if (item->type() == NetworkManager::ConnectionSettings::Wireless && !specificPath.isEmpty()) {
@@ -769,7 +767,7 @@ void NetworkModel::availableConnectionDisappeared(const QString &connection)
 
             if (item->duplicate()) {
                 removeItem(item);
-                qCDebug(PLASMA_NM) << "Duplicate item " << item->name() << " removed completely";
+                qCDebug(PLASMA_NM_LIBS_LOG) << "Duplicate item " << item->name() << " removed completely";
             } else {
                 updateItem(item);
             }
@@ -813,7 +811,7 @@ void NetworkModel::connectionRemoved(const QString &connection)
                 item->setTimestamp(QDateTime());
                 item->setUuid(QString());
                 updateItem(item);
-                qCDebug(PLASMA_NM) << "Item " << item->name() << ": connection removed";
+                qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": connection removed";
             }
         } else {
             remove = true;
@@ -821,7 +819,7 @@ void NetworkModel::connectionRemoved(const QString &connection)
 
         if (remove) {
             removeItem(item);
-            qCDebug(PLASMA_NM) << "Item " << item->name() << " removed completely";
+            qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << " removed completely";
         }
         remove = false;
     }
@@ -829,7 +827,7 @@ void NetworkModel::connectionRemoved(const QString &connection)
 
 void NetworkModel::connectionUpdated()
 {
-    NetworkManager::Connection *connectionPtr = qobject_cast<NetworkManager::Connection *>(sender());
+    auto connectionPtr = qobject_cast<NetworkManager::Connection *>(sender());
     if (!connectionPtr) {
         return;
     }
@@ -852,7 +850,7 @@ void NetworkModel::connectionUpdated()
         }
 
         updateItem(item);
-        qCDebug(PLASMA_NM) << "Item " << item->name() << ": connection updated";
+        qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": connection updated";
     }
 }
 
@@ -888,7 +886,7 @@ void NetworkModel::deviceStateChanged(NetworkManager::Device::State state,
     for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
         item->setDeviceState(state);
         updateItem(item);
-        // qCDebug(PLASMA_NM) << "Item " << item->name() << ": device state changed to " << item->deviceState();
+        // qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": device state changed to " << item->deviceState();
     }
 }
 
@@ -896,7 +894,7 @@ void NetworkModel::deviceStateChanged(NetworkManager::Device::State state,
 void NetworkModel::gsmNetworkAccessTechnologiesChanged(QFlags<MMModemAccessTechnology> accessTechnologies)
 {
     Q_UNUSED(accessTechnologies);
-    ModemManager::Modem *gsmNetwork = qobject_cast<ModemManager::Modem *>(sender());
+    auto gsmNetwork = qobject_cast<ModemManager::Modem *>(sender());
     if (!gsmNetwork)
         return;
 
@@ -928,7 +926,7 @@ void NetworkModel::gsmNetworkAccessTechnologiesChanged(QFlags<MMModemAccessTechn
 
 void NetworkModel::gsmNetworkCurrentModesChanged()
 {
-    ModemManager::Modem *gsmNetwork = qobject_cast<ModemManager::Modem *>(sender());
+    auto gsmNetwork = qobject_cast<ModemManager::Modem *>(sender());
     if (!gsmNetwork) {
         return;
     }
@@ -959,7 +957,7 @@ void NetworkModel::gsmNetworkCurrentModesChanged()
 
 void NetworkModel::gsmNetworkSignalQualityChanged(const ModemManager::SignalQualityPair &signalQuality)
 {
-    ModemManager::Modem *gsmNetwork = qobject_cast<ModemManager::Modem *>(sender());
+    auto gsmNetwork = qobject_cast<ModemManager::Modem *>(sender());
     if (!gsmNetwork) {
         return;
     }
@@ -1002,13 +1000,13 @@ void NetworkModel::ipConfigChanged()
 
     for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
         updateItem(item);
-        // qCDebug(PLASMA_NM) << "Item " << item->name() << ": device ipconfig changed";
+        // qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": device ipconfig changed";
     }
 }
 
 void NetworkModel::ipInterfaceChanged()
 {
-    NetworkManager::Device *device = qobject_cast<NetworkManager::Device *>(sender());
+    auto device = qobject_cast<NetworkManager::Device *>(sender());
     if (!device) {
         return;
     }
@@ -1026,7 +1024,7 @@ void NetworkModel::statusChanged(NetworkManager::Status status)
 {
     Q_UNUSED(status);
 
-    qCDebug(PLASMA_NM) << "NetworkManager state changed to " << status;
+    qCDebug(PLASMA_NM_LIBS_LOG) << "NetworkManager state changed to " << status;
     // This has probably effect only for VPN connections
     for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Type, NetworkManager::ConnectionSettings::Vpn)) {
         updateItem(item);
@@ -1054,7 +1052,7 @@ void NetworkModel::wirelessNetworkDisappeared(const QString &ssid)
         // Remove the entire item, because it's only AP or it's a duplicated available connection
         if (item->itemType() == NetworkModelItem::AvailableAccessPoint || item->duplicate()) {
             removeItem(item);
-            qCDebug(PLASMA_NM) << "Wireless network " << item->name() << " removed completely";
+            qCDebug(PLASMA_NM_LIBS_LOG) << "Wireless network " << item->name() << " removed completely";
             // Remove only AP and device from the item and leave it as an unavailable connection
         } else {
             if (item->mode() == NetworkManager::WirelessSetting::Infrastructure) {
@@ -1064,14 +1062,14 @@ void NetworkModel::wirelessNetworkDisappeared(const QString &ssid)
             }
             item->setSignal(0);
             updateItem(item);
-            qCDebug(PLASMA_NM) << "Item " << item->name() << ": wireless network removed";
+            qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": wireless network removed";
         }
     }
 }
 
 void NetworkModel::wirelessNetworkReferenceApChanged(const QString &accessPoint)
 {
-    NetworkManager::WirelessNetwork *networkPtr = qobject_cast<NetworkManager::WirelessNetwork *>(sender());
+    auto networkPtr = qobject_cast<NetworkManager::WirelessNetwork *>(sender());
 
     if (!networkPtr) {
         return;
@@ -1098,7 +1096,7 @@ void NetworkModel::wirelessNetworkReferenceApChanged(const QString &accessPoint)
 
 void NetworkModel::wirelessNetworkSignalChanged(int signal)
 {
-    NetworkManager::WirelessNetwork *networkPtr = qobject_cast<NetworkManager::WirelessNetwork *>(sender());
+    auto networkPtr = qobject_cast<NetworkManager::WirelessNetwork *>(sender());
     if (!networkPtr) {
         return;
     }
@@ -1107,7 +1105,7 @@ void NetworkModel::wirelessNetworkSignalChanged(int signal)
         if (item->specificPath() == networkPtr->referenceAccessPoint()->uni()) {
             item->setSignal(signal);
             updateItem(item);
-            // qCDebug(PLASMA_NM) << "Wireless network " << item->name() << ": signal changed to " << item->signal();
+            // qCDebug(PLASMA_NM_LIBS_LOG) << "Wireless network " << item->name() << ": signal changed to " << item->signal();
         }
     }
 }
@@ -1148,7 +1146,7 @@ void NetworkModel::updateFromWirelessNetwork(NetworkModelItem *item,
             connection->settings()->setting(NetworkManager::Setting::Wireless).staticCast<NetworkManager::WirelessSetting>();
         if (wirelessSetting) {
             if (!wirelessSetting->bssid().isEmpty()) {
-                for (const NetworkManager::AccessPoint::Ptr ap : network->accessPoints()) {
+                for (const NetworkManager::AccessPoint::Ptr &ap : network->accessPoints()) {
                     if (ap->hardwareAddress() == NetworkManager::macAddressAsString(wirelessSetting->bssid())) {
                         item->setSignal(ap->signalStrength());
                         item->setSpecificPath(ap->uni());
